/** Represents a Client */

class Client {
    constructor() {
            this._got = require('got')
            this._ENDPOINT = "https://labsapi.thehostkiller.tk"
            this._token = ""
        }
        /**
         * Login the client with an API token.
         * @param {string} token - The API token.  
         * @return {string}  
         */
    login(token) {
            this._token = token
            return token
        }
        /**
         * Do a web request.
         * @param {string} url - The URL for the request.
         * @param {string} body - The content for the web request.
         * @param {object} headers - The headers for the web request.
         * @return {Promise}  
         */
    _request(url, body, headers) {
            return this._got.get(url, {
                body: body,
                headers: headers
            }).catch(e => {})
        }
        /**
         * Fetch all bots.
         * @return {Promise}  
         */
    fetchBots() {
            return new Promise(async(resolve, reject) => {
                const rs = await this._request(this._ENDPOINT + "/bots", "", {
                    "Authorization": this._token
                })
                if (!rs.body) return reject(new Error('Bad endpoint.'))
                const body = JSON.parse(rs.body)
                if (body.error) return reject(new Error(body.error))
                return resolve(body.bots)
            })
        }
        /**
         * Fetch all members.
         * @return {Promise}  
         */
    fetchMembers() {
            return new Promise(async(resolve, reject) => {
                const rs = await this._request(this._ENDPOINT + "/members", "", {
                    "Authorization": this._token
                })
                if (!rs.body) return reject(new Error('Bad endpoint.'))
                const body = JSON.parse(rs.body)
                if (body.error) return reject(new Error(body.error))
                return resolve(body.members)
            })
        }
        /**
         * Get a bot by its id.
         * @param {string} - The bot's id.
         * @return {Promise}  
         */
    getBot(id) {
            return new Promise(async(resolve, reject) => {
                const rs = await this._request(this._ENDPOINT + "/bots/" + id, "", {
                    "Authorization": this._token
                })
                if (!rs.body) return reject(new Error('Bad endpoint.'))
                const body = JSON.parse(rs.body)
                if (body.error) return reject(new Error(body.error))
                return resolve(body)
            })
        }
        /**
         * Get a member by its id.
         * @param {string} id - The member's id.
         * @return {Promise}  
         */
    getMember(id) {
        return new Promise(async(resolve, reject) => {
            const rs = await this._request(this._ENDPOINT + "/members/" + id, "", {
                "Authorization": this._token
            })
            if (!rs.body) return reject(new Error('Bad endpoint.'))
            const body = JSON.parse(rs.body)
            if (body.error) return reject(new Error(body.error))
            return resolve(body)
        })
    }
}

module.exports.Client = Client